Symposium ACP Proxy
This crate provides the Symposium proxy functionality. It sits between an editor and an agent, using sacp-conductor to orchestrate a dynamic chain of component proxies that enrich the agent’s capabilities.
Two modes are supported:
Symposium: Proxy mode - sits between editor and an existing agentSymposiumAgent: Agent mode - wraps a downstream agent
Architecture:
- Receive Initialize request from editor
- Examine capabilities to determine what components are needed
- Build proxy chain dynamically using conductor’s lazy initialization
- Forward Initialize through the chain
- Bidirectionally forward all subsequent messages
Structs
- Symposium
- Symposium in proxy mode - sits between an editor and an existing agent.
- Symposium
Agent - Symposium in agent mode - wraps a downstream agent.